%Code to check Cases 1-3 with Closed Form solutions

%{
Cases 1-3 are all versions of an "Eat the Pie" problem.
Thus, we have the following Consumption and Value Functions

c(W) = (1-delta)*W
v(W) = (1/(1 - delta))*(log(1 - delta) + log(W) + ((delta/(1 - delta)) * (log(R*delta))))

-->Here, W is initial assets plus the present value of all future income flows
%}

%%-------------------------------------------------------------------------
%% Create a vector of possible starting wealth values
%%		-> Agent is endowed with "initialAssets" plus the present value
%%			of all future (deterministic) income flows
	initialAssets = [0:xjump:xmax-1];

	assert(incomeCase == 1) %Deterministic Income
		assert(incomeWorkMin == 1)
		assert(incomeWorkMax == 1)
	discountFactors = R * ones(1, yearsWork);
	discountFactors = 1 ./ (cumprod(discountFactors) ./ R);
		%discountFactors is [1, 1/R, 1/R^2, 1/R^3, ... ]
	pdvIncome = discountFactors * ones(yearsWork, 1);

	W = initialAssets + pdvIncome;
%%-------------------------------------------------------------------------

%%-------------------------------------------------------------------------
%%Consumption and Value Functions
	c_W = (1-delta).*W ;
	v_W = (1/(1 - delta))*(log(1 - delta) + log(W) + ((delta/(1 - delta)) * (log(R*delta)))) ;
%%-------------------------------------------------------------------------


%%-------------------------------------------------------------------------
%%Plot Closed Form vs. Numerical Simulation
%	-->Note: we index C__ and V__ differently in the plots below 
%	since income in period 1 is already realized when consumption
%	and value functions are derived

	checkPlotType = 1

	switch checkPlotType
		case 1
		%Consumption Policy Function
			plot(initialAssets, c_W, X_(xzeroIndex: find(X_ == xmax-1)), C__(find(X_ == 1):end,1))
				 xlabel('Initial Assets (W_t)')
				 ylabel('C(W_t)')
				 legend('Analytic Cons. Fxn', 'Simulated Cons. Fxn', 'Location', 'NW')
				 grid on
		 
		case 2
		%Value Function
			plot(initialAssets, v_W, X_(xzeroIndex: find(X_ == xmax-1)), V__(find(X_ == 1):end,1))
				xlabel('Initial Assets (W_t)')
				ylabel('V(W_t)')
				legend('Analytic Value Fxn', 'Simulated Value Fxn', 'Location', 'NW')
				grid on
	end
%%-------------------------------------------------------------------------