%{
##########################################################################
##########################################################################
Code to generate graphs used in Prof. Laibson's lecture slides

	->Note: step sizes (xjump) are made much smaller for this output, and
			xmax is often expanded. 
			These changes are marked where relevant
##########################################################################
##########################################################################
%}


%%-------------------------------------------------------------------------
%%-------------------------------------------------------------------------
%{
%%Pre-specified cases
    1. [NS] Deterministic y = 1 during work and y = 0 during infinite
    retirement. R = 1.01. delta*R = 1. Log utility. No liquidity constraint
	
    2. [NS] Case 1, but now delta = 0.9
    
    3. [S] Case 2, but infinite working life and no retirement

    4. [S] Case 3, but with stochastic income f(y) = uniform[0.5, 1.5]

    5. [NS] Case 4, but with calibrated #years working and #years retired

    6. [NS] Case 5, but with a liquidity constraint R(x_t - c_t) >= -0.5
	----------------------------
	0. User-defined case
%}

graphCase = 1.1
switch graphCase

%%-------------------------------------------------------------------------
%Case 1:
	%{
	Graphs are: 1. consumption fxn at t = 0;
				2. value fxn at t = 0;
				3. consumption fxn in 5-year increments
	%}
	case 1.1
		assert(step == 1)
			assert(yearsWork==51 & incomeCase == 1)
		assert(xjump <= 0.01)	
		
		fig = plot(X_, C__(:,1));
		title('Case 1: Consumption Policy Function at t = 1')
		xlabel('X_t')
        ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 2.5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_1pt1.png')
	
	case 1.2
		assert(step == 1)
			assert(yearsWork==51 & incomeCase == 1)
		assert(xjump <= 0.01)
		
		fig = plot(X_, V__(:,1));
		title('Case 1: Value Function at t = 1')
		xlabel('X_t')
        ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues		
		axis([0 30 -5 20])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_1pt2.png')
		
	case 1.3
		assert(step == 1)
			assert(yearsWork==51 & incomeCase == 1)
		assert(xjump <= 0.01)
		
		years_to_display = [1:5:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 1: Consumption Policy Function at t \in [1, 5, 11, ..., 51]')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 2.5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_1pt3.png')
	
%%-------------------------------------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%-------------------------------------------------------------------------
%Case 2:
	%{
	Graphs are: 1. consumption fxn at t = 0;
				2. value fxn at t = 0;
				3. consumption fxn in 5-year increments
	%}
	case 2.1
		assert(step == 2)
			assert(yearsWork==51 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)	
		
		fig = plot(X_, C__(:,1));
		title('Case 2: Consumption Policy Function at t = 1')
		xlabel('X_t')
        ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_2pt1.png')
	
	case 2.2
		assert(step == 2)
			assert(yearsWork==51 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)
		
		fig = plot(X_, V__(:,1));
		title('Case 2: Value Function at t = 1')
		xlabel('X_t')
        ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues		
		axis([0 30 0 12])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_2pt2.png')
		
	case 2.3
		assert(step == 2)
			assert(yearsWork==51 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:5:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 2: Consumption Policy Function at t \in [1, 5, 11, ..., 51]')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_2pt3.png')

%%-------------------------------------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%-------------------------------------------------------------------------
%Case 3:
	%{
	Graphs are: 1. consumption fxn at t = 0;
				2. value fxn at t = 0;
				3. consumption fxn in 5-year increments (to show convergence)
				4. value fxn in 5-year increments (to show convergence)
	%}
	case 3.1
		assert(step == 3)
			assert(yearsWork==251 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)	
		
		fig = plot(X_, C__(:,1));
		title('Case 3: Consumption Policy Function at t = 1')
		xlabel('X_t')
        ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_3pt1.png')
	
	case 3.2
		assert(step == 3)
			assert(yearsWork==251 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)
		
		fig = plot(X_, V__(:,1));
		title('Case 3: Value Function at t = 1')
		xlabel('X_t')
        ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues		
		axis([0 30 0 12])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_3pt2.png')
		
		
	case 3.3
		assert(step == 3)
			assert(yearsWork==251 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 3: Consumption Policy Function Convergence')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_3pt3.png')	

	case 3.4
		assert(step == 3)
			assert(yearsWork==251 & incomeCase == 1 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, V__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, V__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 3: Value Function Convergence')
		xlabel('X_t')
		ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([0 30 -5 20])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_3pt4.png')	

%%-------------------------------------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%-------------------------------------------------------------------------
%Case 4:
	%{
	Graphs are: 1. consumption fxn at t = 0;
				2. value fxn at t = 0;
				3. consumption fxn in 5-year increments (to show convergence)
				4. value fxn in 5-year increments (to show convergence)
	%}		
	case 4.1
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)	
		
		fig = plot(X_, C__(:,1));
		title('Case 4: Consumption Policy Function at t = 1')
		xlabel('X_t')
        ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt1.png')
	
	case 4.2
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
		
		fig = plot(X_, V__(:,1));
		title('Case 4: Value Function at t = 1')
		xlabel('X_t')
        ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues		
		axis([0 30 0 12])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt2.png')
		

	case 4.3
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 4: Consumption Policy Function Convergence')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt3.png')

	case 4.31
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
		assert(eolRepay ~= 1)
	
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 4: Consumption Policy Function Convergence')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt3_NoEOLRepay.png')	
		
		
	case 4.4
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, V__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, V__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 4: Value Function Convergence')
		xlabel('X_t')
		ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([0 30 -5 20])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt4.png')

	case 4.41
		assert(step == 4)
			assert(yearsWork==251 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
		assert(eolRepay ~= 1)
		
		years_to_display = [1:1:yearsWork];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, V__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, V__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 4: Value Function Convergence')
		xlabel('X_t')
		ylabel('V_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([0 30 -5 20])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_4pt4_NoEOLRepay.png')	

%%-------------------------------------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%-------------------------------------------------------------------------
%Case 5:
	%{
	Graphs are: 1. consumption fxn in 5-year increments
				2. Avg time path
	%}	
	case 5.1
		assert(step == 5)
			assert(yearsWork==51 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:5:yearsAlive];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 5: Consumption Policy Function at Age \in [20, 25, 30, ..., 90]')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-20 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_5pt1.png')
	
	case 5.2
		age_ = [20:20+yearsAlive-1];
		fig = plot(age_, mean(realX__), 'r+', age_, mean(realSavings__), 'bo', age_, mean(realC__), 'g*')
		title('Case 5: Average Profiles')
		legend('X', 'Savings', 'C', 'Location', 'SE')
		xlabel('Age')
		grid on
		
		saveas(gcf, 'graphs_for_lecture/graph_output/graph_5pt2.png')

%%-------------------------------------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%-------------------------------------------------------------------------
%Case 6:
	%{
	Graphs are: 1. consumption fxn in 5-year increments
				2. Avg time path
				3. path of single person
	%}	
	case 6.1
		assert(step == 6)
			assert(yearsWork==51 & incomeCase == 2 & xmax == 50)
		assert(xjump <= 0.01)
	
		years_to_display = [1:5:yearsAlive];
			for i = 1:length(years_to_display);
				colorscale = i / length(years_to_display);
				if years_to_display(i) > yearsWork;
					fig = plot(X_, C__(:, years_to_display(i)), 'Color', 'Black')
				else
					fig = plot(X_, C__(:, years_to_display(i)), 'Color',[0, 1-colorscale, .7])
				end
				hold on
			end
		hold off
		title('Case 6: Consumption Policy Function at Age \in [20, 25, 30, ..., 90]')
		xlabel('X_t')
		ylabel('C_t')
		grid on
		%Cut off so we avoid xmax issues
		axis([-1 30 0 5])
		
		saveas(fig, 'graphs_for_lecture/graph_output/graph_6pt1.png')
	
	case 6.2
		assert(step == 6)
			assert(yearsWork==51 & incomeCase == 2 & xmax >= 10)
		assert(xjump <= 0.01)

		age_ = [20:20+yearsAlive-1];
		credConstraint = borrowingLimit .* ones(length(age_));
		fig = plot(age_, mean(realX__), 'r+', age_, mean(realSavings__), 'bo', age_, ...
			 mean(realC__), 'g*', age_, credConstraint, 'black-')
		title('Case 6: Average Profiles')
		legend({'X', 'Savings', 'C', '-L * R'}, 'Location', 'NW')%, 'Interpreter', 'latex')
		xlabel('Age')
		grid on
		
		saveas(gcf, 'graphs_for_lecture/graph_output/graph_6pt2.png')
	
	case 6.3
		assert(step == 6)
			assert(yearsWork==51 & incomeCase == 2 & xmax >= 10)
		assert(xjump <= 0.01)

		 person = 50;
		age_ = [20:20+yearsAlive-1];
		credConstraint = borrowingLimit .* ones(length(age_));
		fig = plot(age_, mean(realSavings__), ':', age_, realSavings__(person, :), 'bo', ...
			age_, realC__(person, :), 'g*', age_, realY__(person, :), 'blas', age_, credConstraint, 'black-')
		title('Case 6: Profile of Single Agent')
		legend({'Average Saving of Population', 'Saving', 'C', 'Y',  '-L * R'}, 'Location', 'NW') %, 'Interpreter', 'latex')
		xlabel('Age')
		grid on
		axis([20 90 -1 5])
		
		saveas(gcf, 'graphs_for_lecture/graph_output/graph_6pt3.png')	
		
		
end