function [Xstruct] = buildX_(borrowingLimit, xmax, xjump, incomeWorkMin, incomeWorkMax)
%Create Savings Account X
%    Let X_ denote the vector of all possible X_t values in the simulation
%    This section builds variable X_.


		%----------
        %NOTE: Lower xjump means a better approximation of continuous 
		%	   savings acct,but comes at cost of higher run-time
        %      Similarly, higher xmax means agent allowed to save more, 
        %      but also comes at cost of higher run-time
		%----------
		
    X_ = [borrowingLimit:xjump:xmax];
    xlen = length(X_);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %A few necessary variables / conditions
	%	Note: if these conditons do not hold, it likely stems from the borrowingLimit
	%		We discretize X, starting at borrowingLimit and ending at xmax. The conditions
	%		below ensure that we hit certain points in that discretized state space
    assert( ~isempty( find(X_ == 0) ) )
	assert( ~isempty( find(X_ == incomeWorkMin) ) )
	assert( ~isempty( find(X_ == incomeWorkMax) ) )
    xzeroIndex = find(X_ == 0);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	
	Xstruct = struct('X_', X_, ...
					'xlen', xlen, ... 
					'xzeroIndex', xzeroIndex, ...
					'xjump', xjump,  ...
					'xmax', xmax, ...
					'borrowingLimit', borrowingLimit);
	
end

